translate.tools.pocount.summarizer

Package translate :: Package tools :: Module pocount :: Class summarizer |
[hide private]
[frames] | no frames]

# Class summarizer

source code

Instance Methods | [hide private]
__init__(self, filenames, style=0, incomplete_only=False) | source code
updatetotals(self, stats) Update self.totals with the statistics in stats. | source code
handlefile(self, filename) | source code
handlefiles(self, dirname, filenames) | source code
handledir(self, dirname) | source code